/*
 * Copyright (c) 2019 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef __TIZEN_COMPONENT_BASED_BASE_FRAME_COMPONENT_H__
#define __TIZEN_COMPONENT_BASED_BASE_FRAME_COMPONENT_H__

#include <app_control.h>
#include <bundle.h>

#include <component_common.h>

#ifdef __cplusplus
extern "C" {
#endif

typedef struct frame_window_s *frame_window_h;

int base_frame_create_window(frame_window_h *handle, int id, void *raw);
int base_frame_window_get_id(frame_window_h handle, int *id);
int base_frame_window_get_raw(frame_window_h handle, void **raw);
int base_frame_get_display_status(
		component_h context, component_display_status_e *display_status);

typedef frame_window_h (*base_frame_component_create_cb)(
		component_h context,
		void *user_data);

typedef void (*base_frame_component_start_cb)(
		component_h context,
		app_control_h app_control,
		bool restarted,
		void *user_data);

typedef void (*base_frame_component_resume_cb)(
		component_h context,
		void *user_data);

typedef void (*base_frame_component_pause_cb)(
		component_h context,
		void *user_data);

typedef void (*base_frame_component_stop_cb)(
		component_h context,
		void *user_data);

typedef void (*base_frame_component_destroy_cb)(
		component_h context,
		void *user_data);

typedef void (*base_frame_component_restore_content_cb)(
		component_h context,
		bundle *content,
		void *user_data);

typedef void (*base_frame_component_save_content_cb)(
		component_h context,
		bundle *content,
		void *user_data);

typedef void (*base_frame_component_action_cb)(
		component_h context,
		const char *action,
		app_control_h app_control,
		void *user_data);

typedef void (*base_frame_component_device_orientation_changed_cb)(
		component_h context,
		component_device_orientation_e orientation,
		void *user_data);

typedef void (*base_frame_component_language_changed_cb)(
		component_h context,
		const char *language,
		void *user_data);

typedef void (*base_frame_component_region_format_changed_cb)(
		component_h context,
		const char *region,
		void *user_data);

typedef void (*base_frame_component_low_battery_cb)(
		component_h context,
		component_low_battery_status_e status,
		void *user_data);

typedef void (*base_frame_component_low_memory_cb)(
		component_h context,
		component_low_memory_status_e status,
		void *user_data);

typedef void (*base_frame_component_suspended_state_changed_cb)(
		component_h context,
		component_suspended_state_e state,
		void *user_data);

typedef struct {
	base_frame_component_create_cb create;
	base_frame_component_start_cb start;
	base_frame_component_resume_cb resume;
	base_frame_component_pause_cb pause;
	base_frame_component_stop_cb stop;
	base_frame_component_destroy_cb destroy;
	base_frame_component_restore_content_cb restore_content;
	base_frame_component_save_content_cb save_content;
	base_frame_component_action_cb action;
	base_frame_component_device_orientation_changed_cb device_orientation_changed;
	base_frame_component_language_changed_cb language_changed;
	base_frame_component_region_format_changed_cb region_format_changed;
	base_frame_component_low_battery_cb low_battery;
	base_frame_component_low_memory_cb low_memory;
	base_frame_component_suspended_state_changed_cb suspended_state_changed;
} base_frame_component_lifecycle_callback_s;

#ifdef __cplusplus
}
#endif

#endif /* __TIZEN_COMPONENT_BASED_BASE_FRAME_COMPONENT_H__ */

