/*
 * Copyright (c) 2019 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef COMPONENT_BASED_BASE_DEVICE_ORIENTATION_H_
#define COMPONENT_BASED_BASE_DEVICE_ORIENTATION_H_

#include <string>

#ifndef EXPORT_API
#define EXPORT_API __attribute__((visibility("default")))
#endif

namespace component_based {

class EXPORT_API DeviceOrientation {
 private:
  DeviceOrientation() = default;
  ~DeviceOrientation() = default;

 public:
  enum class Orientation {
    Orientation_0 = 0,
    Orientation_90 = 90,
    Orientation_180 = 180,
    Orientation_270 = 270,
  };

  static std::string ToString(Orientation orientation) {
    switch (orientation) {
    case Orientation::Orientation_90:
      return "Orientation_90";
    case Orientation::Orientation_180:
      return "Orientation_180";
    case Orientation::Orientation_270:
      return "Orientation_270";
    default:
      return "Orientation_0";
    }
  }
};

}  // namespace component_based

#endif  // COMPONENT_BASED_BASE_DEVICE_ORIENTATION_H_
