/*
 * Copyright (c) 2019 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef COMPONENT_BASED_BASE_LOW_MEMORY_H_
#define COMPONENT_BASED_BASE_LOW_MEMORY_H_

#include <string>

#ifndef EXPORT_API
#define EXPORT_API __attribute__((visibility("default")))
#endif

namespace component_based {

class EXPORT_API LowMemory {
 private:
  LowMemory() = default;
  ~LowMemory() = default;

 public:
  enum class Status {
    None = 0x00,
    Normal = 0x01,
    SoftWarning = 0x02,
    HardWarning = 0x04,
  };

  static std::string ToString(Status status) {
    switch(status) {
    case Status::Normal:
      return "Normal";
    case Status::SoftWarning:
      return "SoftWarning";
    case Status::HardWarning:
      return "HwardWarning";
    default:
      return "None";
    }
  }
};

}  // namespace component_based

#endif  // COMPONENT_BASED_BASE_LOW_MEMORY_H_
