/*
 * Copyright (c) 2019 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <dlog.h>
#include <Elementary.h>

#include <memory>

#include "component_based/efl_base/application.h"

#ifdef LOG_TAG
#undef LOG_TAG
#endif

#define LOG_TAG "CAPI_APPFW_COMPONENT_BASED_APPLICATION"

namespace component_based {

Application::Application() {
}

Application::~Application() = default;

void Application::OnInit(int argc, char** argv) {
  LOGD("");
  elm_init(argc, argv);
  const char* hwacc = getenv("HWACC");
  if (hwacc && !strcmp(hwacc, "USE")) {
    elm_config_accel_preference_set("hw");
    LOGD("elm_config_accel_preference_set: hw");
  } else if (hwacc && !strcmp(hwacc, "NOT_USE")) {
    elm_config_accel_preference_set("none");
    LOGD("elm_config_accel_preference_set: none");
  } else {
    LOGD("elm_config_accel_preference_set is not called");
  }
}

void Application::OnFini() {
  LOGD("");
  elm_shutdown();

  // Check loader case
  if (getenv("AUL_LOADER_INIT")) {
    unsetenv("AUL_LOADER_INIT");
    elm_shutdown();
  }
}

void Application::OnRun() {
  LOGD("");
  elm_run();
}

void Application::OnExit() {
  LOGD("");
  elm_exit();
}

}  // namespace component_based
