/*
 * Copyright (c) 2019 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef COMPONENT_BASED_URI_COMPONENT_BASED_URI_H_
#define COMPONENT_BASED_URI_COMPONENT_BASED_URI_H_

#include <string>
#include <list>
#include <memory>

#include "component_based/uri/component_based_query.h"

#ifndef EXPORT_API
#define EXPORT_API __attribute__((visibility("default")))
#endif

namespace component_based {

class EXPORT_API Uri {
 public:
  class Builder {
   public:
    virtual ~Builder();
    Builder& SetScheme(std::string scheme);
    Builder& SetAuthority(std::string auth);
    Builder& SetPath(std::string path);
    Builder& AddPath(std::string path);
    Builder& SetFragment(std::string framgment);
    Builder& AddQuery(std::string key, std::string value);
    Uri Build();

   private:
    std::string scheme_;
    std::string auth_;
    std::string path_;
    std::string fragment_;
    std::list<Query> query_list_;
  };

  Uri();
  explicit Uri(std::string encoded_uri);
  Uri(std::string scheme, std::string auth,
      std::string path, std::list<Query> query,
      std::string fragment);
  virtual ~Uri();

  const std::string& GetScheme() const;
  const std::string& GetAuthority() const;
  const std::string& GetPath() const;
  const std::string& GetFragment() const;
  const std::list<Query>& GetQuery() const;
  const std::string& GetHost() const;
  const std::string& GetPort() const;
  const std::string& GetUser() const;
  std::string Encode() const;

 private:
  void Parse(const std::string& uri);
  void ParseScheme(const std::string& uri);
  void ParseAuthority(const std::string& uri);
  void ParsePath(const std::string& uri);
  void ParseQuery(const std::string& uri);
  void ParseFragment(const std::string& uri);
  void ParseAuthoritySubComponent(const std::string& auth);
  void AddQuery(const std::string& query);
  bool IsNumber(const std::string& s);

 private:
  std::size_t idx_ = 0;

 private:
  std::string scheme_;
  std::string auth_;
  std::string path_;
  std::list<Query> query_list_;
  std::string fragment_;
  std::string host_;
  std::string port_;
  std::string user_;
};

}  // namespace component_based

#endif  // COMPONENT_BASED_URI_COMPONENT_BASED_URI_H_
